CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
48 lines
1.5 KiB
C++
48 lines
1.5 KiB
C++
// Copyright (c) 2026 Advanced Micro Devices, Inc.
|
|
// SPDX-License-Identifier: MIT
|
|
|
|
// Regression test for v_bfe_u32 (vector bit-field extract).
|
|
// A 2D HIP grid uses v_bfe_u32 to extract threadIdx.y from the packed
|
|
// thread-ID register. If v_bfe_u32 is broken, threadIdx.y is always 0
|
|
// and only half the output is written.
|
|
|
|
#include <hip/hip_runtime.h>
|
|
#include <unistd.h>
|
|
#include <vector>
|
|
|
|
#include <gtest/gtest.h>
|
|
|
|
int main(int argc, char **argv) {
|
|
::testing::InitGoogleTest(&argc, argv);
|
|
return RUN_ALL_TESTS();
|
|
}
|
|
|
|
#define HIP_ASSERT(call) \
|
|
do { \
|
|
hipError_t err = (call); \
|
|
ASSERT_EQ(err, hipSuccess) << "HIP error: " << hipGetErrorString(err); \
|
|
} while (0)
|
|
|
|
__global__ void write_thread_y(int *out) { out[threadIdx.y] = threadIdx.y; }
|
|
|
|
TEST(BfeRegressionTest, ThreadIdxY) {
|
|
constexpr int N = 4;
|
|
|
|
int *d_out = nullptr;
|
|
HIP_ASSERT(hipMalloc(&d_out, N * sizeof(int)));
|
|
HIP_ASSERT(hipMemset(d_out, -1, N * sizeof(int)));
|
|
|
|
dim3 block(1, N);
|
|
dim3 grid(1, 1);
|
|
write_thread_y<<<grid, block>>>(d_out);
|
|
HIP_ASSERT(hipDeviceSynchronize());
|
|
|
|
std::vector<int> h(N);
|
|
HIP_ASSERT(hipMemcpy(h.data(), d_out, N * sizeof(int), hipMemcpyDeviceToHost));
|
|
|
|
for (int i = 0; i < N; ++i)
|
|
EXPECT_EQ(h[i], i);
|
|
|
|
(void)hipFree(d_out);
|
|
}
|